@@ -1,6 +1,6 @@
 package OpenTracing::Implementation::Test::Tracer;
 
-our $VERSION = 'v0.103.0';
+our $VERSION = 'v0.103.1';
 
 use Moo;
 
@@ -270,7 +270,8 @@ sub cmp_deeply {
 }
 
 sub cmp_easy {
-    $_[1] = superbagof(map { superhashof($_) } @$_[1]);
+    my $exp = $_[1];
+    $_[1] = superbagof(map { superhashof($_) } @$exp);
     goto &cmp_deeply;
 }
 
